module Dolmade

  require "httparty"

  class Rapleaf

    include HTTParty
    format :json
    base_uri "https://personalize.rapleaf.com/v4"
    # debug_output $stderr

    attr_accessor :api_key
   
    def initialize(api_key)
      self.api_key = api_key
    end

    def lookup_by_email(email)
      if email.respond_to?(:map)
        result = bulk_lookup_by_email(email)
        result.map! { |e| Person.new(e) }
      else
        Person.new(self.request({:email => email}))
      end
    end

    protected

    def request(query={})
      query.merge!({:api_key => self.api_key})
      self.class.get('/dr',{:query => query})
    end

    def bulk_lookup_by_email(emails)
      emails.map! { |e| {'email' => e} }
      self.class.post('/bulk', {:query => {:api_key => self.api_key}, :body => emails.to_json, :headers => {'Content-Type' => 'application/json'}})
    end
   
  end

  class Person

    attr_accessor :age, :gender, :country, :state

    def initialize(obj)
      self.age = obj['age']
      self.gender = obj['gender']
      self.country = obj['country']
      self.state = obj['state']
    end

  end

end